import {environment} from '../../../../environments/environment';
import {DateService} from '../../../business/services/util/date.service';
import {NzMessageService} from 'ng-zorro-antd';
import {Component, OnInit} from '@angular/core';
import {HttpClient} from '@angular/common/http';
import {Router} from '@angular/router';

@Component({
  selector: 'app-demo',
  templateUrl: './demo.component.html',
  styles: []
})

export class DemoComponent implements OnInit {
  [x: string]: any;
  public query: any = {};
  public sensorOptions = [];
  public typeOptions = [
    {value: 'year', label: '年', format: 'YYYY'},
    {value: 'month', label: '月', format: 'YYYY-MM'},
    {value: 'day', label: '日', format: 'YYYY-MM-DD'},
    {value: 'hour', label: '时', format: 'YYYY-MM-DD HH'}
  ];
  public reportOptions = [
    {value: 'bar', label: '柱状图'},
    {value: 'line', label: '折线图'}
  ];
  public monitorPointOptions = [];
  public items = [{
    id: 0,
    monitorPoint: null,
    device: null,
    time: null,
    deviceOptions: []
  }];

  constructor(
    public http: HttpClient,
    public dateSrv: DateService,
    public router: Router,
    public msgSrv: NzMessageService
  ) {
    this.timeType = this.typeOptions[1];
    this.query.reportType = this.reportOptions[1].value;
  }

  ngOnInit() {
    this.http.get(environment.SERVER_BASH_URL + 'sensor/all').subscribe((res: any) => {
      if (res.code === 0) {
        this.msgSrv.error(res.message);
      } else {
        this.sensorOptions = res.data;
      }
    });
  }

  addItem() {
    const id = (this.items.length > 0) ? this.items[this.items.length - 1].id + 1 : 0;
    const index = this.items.push({
      id: id,
      monitorPoint: null,
      device: null,
      time: null,
      deviceOptions: []
    });
  }

  searchChange(searchText, i) {
    if (searchText) {
      const query = encodeURI(searchText);
      if (query) {
        this.http.get(environment.SERVER_BASH_URL + '/monitor-point/list/' + query).subscribe((res: any) => {
          if (res.code === 0) {
            this.msgSrv.error(res.message);
          } else {
            this.monitorPointOptions = res.data;
          }
        });
      }
    }
  }

  monitorPointChange(value, i) {
    this.items[i].deviceOptions = [];
    this.items[i].device = null;
    if (value) {
      this.http.get(environment.SERVER_BASH_URL + 'device/monitorPointId', {params: {monitorPointId: value.id}}).subscribe((res: any) => {
        if (res.code === 0) {
          this.msgSrv.error(res.message);
        } else {
          this.items[i].deviceOptions = res.data;
        }
      });
    }
  }

  _disabledDate(current: Date): boolean {
    return current && current.getTime() > Date.now();
  }

  reportQuery() {
    const query = this.query;
    let validate = true;
    const queryItems = [];
    for (let i = 0; i < this.items.length; i++) {
      let item = this.items[i];
      let queryItem: any = {};
      if (item.monitorPoint && item.time) {
        for (var key in item) {
          if (item[key]) {
            queryItem[key] = item[key];
          }
        }
        queryItem.monitorPointId = queryItem.monitorPoint.id;
        queryItem.monitorPointName = queryItem.monitorPoint.name;
        queryItem.monitorPointAddress = queryItem.monitorPoint.address;
        delete queryItem.monitorPoint;
        if (queryItem.device) {
          queryItem.mac = queryItem.device.mac;
          queryItem.deviceName = queryItem.device.name;
          delete queryItem.device;
        }
        queryItem.deviceCount = queryItem.deviceOptions.length;
        delete queryItem.deviceOptions;
        queryItem.formatTime = this.dateSrv.date_format(queryItem.time, this.timeType.format);
        delete queryItem.time;
        queryItems.push(queryItem);
      } else {
        validate = false;
        break;
      }
    }
    if (validate && this.timeType && query.reportType) {
      if (query.sensorKey && query.sensorKey.length > 0) {
        query.sensors = JSON.stringify(query.sensorKey);
      }
      query.items = JSON.stringify(queryItems);
      query.type = this.timeType.value;
      this.router.navigate(['report'], {queryParams: query});
    } else {
      this.msgSrv.error('请完善搜索项或删除查询条目');
    }
  }
}
